<?php
/*  
Plugin Name: Jigoshop Basic Bundle Shipping
Plugin URI: http://www.polevaultweb.com/plugins/jigoshop-basic-bundle-shipping/ 
Description: Plugin to extend the Jigoshop shipping rates with a basic bundle rate.
Author: polevaultweb 
Version: 1.0.1
Author URI: http://www.polevaultweb.com/

Copyright 2012  polevaultweb  (email : info@polevaultweb.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as 
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


add_action( 'plugins_loaded', 'jbbs_jigoshop_basic_bundle_shipping_load', 0 );

function jbbs_jigoshop_basic_bundle_shipping_load() {
	
	if ( !class_exists( 'jigoshop_shipping_method' ) ) return;
	
	function add_basic_bundle_method( $methods ) {
		$methods[] = 'jbbs_jigoshop_basic_bundle_shipping'; 
		return $methods;
	}
	add_filter('jigoshop_shipping_methods', 'add_basic_bundle_method' );	
	
	class jbbs_jigoshop_basic_bundle_shipping extends jigoshop_shipping_method {

		public function __construct() {
			
			parent::__construct();
			
			$this->id 			= 'basic_bundle';
			$this->enabled		= Jigoshop_Base::get_options()->get_option('jigoshop_basic_bundle_enabled');
			$this->title 		= Jigoshop_Base::get_options()->get_option('jigoshop_basic_bundle_title');
			$this->first 		= Jigoshop_Base::get_options()->get_option('jigoshop_basic_bundle_first');
			$this->further 		= Jigoshop_Base::get_options()->get_option('jigoshop_basic_bundle_further');
			$this->cap 			= Jigoshop_Base::get_options()->get_option('jigoshop_basic_bundle_cap');

	
			add_action( 'jigoshop_settings_scripts', array( &$this, 'admin_scripts' ) );
			
	    }
	
		/**
		 * Default Option settings for WordPress Settings API using the Jigoshop_Options class
		 *
		 * These should be installed on the Jigoshop_Options 'Shipping' tab
		 *
		 */	
		protected function get_default_options() {
		
			$defaults = array();
			
			// Define the Section name for the Jigoshop_Options
			$defaults[] = array( 'name' => __('Flat Rates', 'jigoshop'), 'type' => 'title', 'desc' => __('Flat rates let you define a standard rate per item, or per order.', 'jigoshop') );
			
			// List each option in order of appearance with details
			$defaults[] = array(
				'name'		=> __('Enable Basic Bundle Rate','jigoshop'),
				'desc' 		=> '',
				'tip' 		=> '',
				'id' 		=> 'jigoshop_basic_bundle_enabled',
				'std' 		=> 'yes',
				'type' 		=> 'checkbox',
				'choices'	=> array(
					'no'			=> __('No', 'jigoshop'),
					'yes'			=> __('Yes', 'jigoshop')
				)
			);
			
			$defaults[] = array(
				'name'		=> __('Method Title','jigoshop'),
				'desc' 		=> '',
				'tip' 		=> __('This controls the title which the user sees during checkout.','jigoshop'),
				'id' 		=> 'jigoshop_basic_bundle_title',
				'std' 		=> __('Basic Bundle Rate','jigoshop'),
				'type' 		=> 'text'
			);
			
			$defaults[] = array(
				'name'		=> __('Price for First Product','jigoshop'),
				'desc' 		=> '',
				'type' 		=> 'decimal',
				'tip' 		=> __('Cost excluding tax. Enter an amount, e.g. 2.50.','jigoshop'),
				'id' 		=> 'jigoshop_basic_bundle_first',
				'std' 		=> '3.50',
			);
			
			$defaults[] = array(
				'name'		=> __('Price for Further Products','jigoshop'),
				'desc' 		=> '',
				'type' 		=> 'decimal',
				'tip' 		=> __('Cost excluding tax. Enter an amount, e.g. 2.50.','jigoshop'),
				'id' 		=> 'jigoshop_basic_bundle_further',
				'std' 		=> '1.OO',
			);
			$defaults[] = array(
				'name'		=> __('Product Number Cap','jigoshop'),
				'desc' 		=> 'This controls the number of products in the cart before the shipping total is capped.',
				'type' 		=> 'decimal',
				'tip' 		=> __('','jigoshop'),
				'id' 		=> 'jigoshop_basic_bundle_further',
				'std' 		=> '5',
			);
			return $defaults;
		}
		
	    public function calculate_shipping() {
		    $this->shipping_total 	= 0;
			$this->shipping_tax 	= 0;
			$this->shipping_label 	= $this->title;
			
			if (sizeof(jigoshop_cart::$cart_contents)>0) {
				
				$num_items = 0;
				foreach (jigoshop_cart::$cart_contents as $item_id => $values) {
					$num_items = $num_items + $values['quantity'];
				}
					  
				if ($num_items == 1) {

					$this->shipping_total = $this->first;
				
				} else {
				
					$num_products = $this->cap;
					if ($num_items < $num_products) {
						$num_products = $num_items;
					}
					
					$cost = $this->first + (($num_products - 1) * $this->further);
					$this->shipping_total = $cost;
				
				}
			}
	    }
	
	}
}
